nx.graphic.Topology.SelectionNodeScene - Next UI Toolkit

#

API Docs for: trial
Show: Inherited Protected Private Deprecated

# nx.graphic.Topology.SelectionNodeScene Class

Extends nx.graphic.Topology.SelectionScene
Module: nx.graphic.Topology

Selection node scene

- Index
- Methods
- Properties

## Item Index

### Methods

- activate
- clearBinding
- deactivate
- dispose
- get
- getBinding
- gets
- has
- notify
- set
- setBinding
- unwatch

### Properties

- selectedNodes

## Methods

### `activate`

()

Inherited from nx.graphic.Topology.Scene

Entry

### `clearBinding`

(

- `prop`

)

Inherited from nx.Observable:

Clear binding for specified property.

#### Parameters:

- `prop` Object

### ``

(

- `names`
- `handler`
- `context`

)

Inherited from nx.Observable:

#### Parameters:

- `names` Object
- `handler` Object
- `context` Object

### `deactivate`

()

Inherited from nx.graphic.Topology.Scene:

Deactivate a scene

### `dispose`

()

Inherited from nx.Observable

Dispose current object.

### `get`

(

- `name`

)

Inherited from nx.data.ObservableObject:

Get specified property value.

#### Parameters:

- `name` String

#### Returns:

:

### `getBinding`

(

- `prop`

)

Inherited from nx.Observable:

Get existing binding object for specified property.

#### Parameters:

- `prop` Object

#### Returns:

:

### `gets`

() Object

Inherited from nx.data.ObservableObject:

Get all properties.

#### Returns:

Object:

### `has`

(

- `name`

)
Boolean

Inherited from nx.data.ObservableObject:

Check whether current object has specified property.

#### Parameters:

- `name` String

#### Returns:

Boolean:

### `notify`

(

- `names`
- `oldValue`

)

Inherited from nx.Observable:

#### Parameters:

- `names` Object
- `oldValue` Object

### `set`

(

- `name`
- `value`

)

Inherited from nx.data.ObservableObject:

Set specified property value.

#### Parameters:

- `name` String
- `value`

### `setBinding`

(

- `prop`
- `expr`
- `source`

)

Inherited from nx.Observable:

Set binding for specified property.

#### Parameters:

- `prop` Object
- `expr` Object
- `source` Object

### `unwatch`

(

- `names`
- `handler`
- `context`

)

Inherited from nx.Observable:

#### Parameters:

- `names` Object
- `handler` Object
- `context` Object

## Properties

### `selectedNodes`

Unknown

Get all selected nodes